pub fn task_to_json(result: &TaskResult) -> ValueExpand description
Serialize task result to JSON.
Paths in the result are already relative to the project root (set at
construction time). Uses scout_to_json() for the scout section.
pub fn task_to_json(result: &TaskResult) -> ValueSerialize task result to JSON.
Paths in the result are already relative to the project root (set at
construction time). Uses scout_to_json() for the scout section.