Module source

Module source 

Source abstraction for indexable content

This module provides the Source trait for abstracting different sources of indexable code (filesystem, SQL Server, etc.).

Structs

FileSystemSource
A source that reads files from the local filesystem
SourceItem
An item to be indexed from a source

Enums

SourceError

Traits

A source of indexable content

Functions

language_from_path
Helper to detect language from file extension