pub struct ImpactResult {
pub function_name: String,
pub callers: Vec<CallerDetail>,
pub tests: Vec<TestInfo>,
pub transitive_callers: Vec<TransitiveCaller>,
pub type_impacted: Vec<TypeImpacted>,
pub degraded: bool,
}Expand description
Complete impact analysis result
Fields
function_name: Stringcallers: Vec<CallerDetail>tests: Vec<TestInfo>transitive_callers: Vec<TransitiveCaller>type_impacted: Vec<TypeImpacted>degraded: boolTrue when batch name search failed and caller snippets may be incomplete. CLI handlers can display a warning when this is set.