Source abstraction for indexable content
This module provides the Source trait for abstracting different
sources of indexable code (filesystem, SQL Server, etc.).
Structs
- File
System Source - A source that reads files from the local filesystem
- Source
Item - An item to be indexed from a source
Enums
Traits
- Source
- A source of indexable content
Functions
- language_
from_ path - Helper to detect language from file extension